summaryrefslogtreecommitdiffstats
path: root/kdesktop/lock/main.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kdesktop/lock/main.cc')
-rw-r--r--kdesktop/lock/main.cc3
1 files changed, 2 insertions, 1 deletions
diff --git a/kdesktop/lock/main.cc b/kdesktop/lock/main.cc
index 4dc9f1e0a..98f59a952 100644
--- a/kdesktop/lock/main.cc
+++ b/kdesktop/lock/main.cc
@@ -277,7 +277,8 @@ int main( int argc, char **argv )
trinity_desktop_lock_use_sak = tdmconfig->readBoolEntry("UseSAK", true);
}
else {
- trinity_desktop_lock_use_sak = false; // If SAK is enabled with unmanaged windows, the SAK dialog will never close and will "burn in" the screen
+ trinity_desktop_lock_use_sak = false; // If SAK is enabled with unmanaged windows, the SAK dialog will never close and will "burn in" the screen
+ trinity_desktop_lock_delay_screensaver_start = false; // If trinity_desktop_lock_delay_screensaver_start is true with unmanaged windows, the lock dialog may never appear
}
delete tdmconfig;